# AI Helpers

Intelligent editing assistants, face analysis, and AI audio generation.
All require optional dependencies: `pip install "pymotion-studio[ai]"`.

## SceneDetector

::: pymotion.ai.SceneDetector

## SilenceRemover

::: pymotion.ai.SilenceRemover

## HighlightDetector

::: pymotion.ai.HighlightDetector

## ContentAwareCrop

::: pymotion.ai.ContentAwareCrop

## AutoColor

::: pymotion.ai.AutoColor

## AutoEdit

::: pymotion.ai.AutoEdit

## FaceDetector

::: pymotion.ai.FaceDetector

## FaceTracker

::: pymotion.ai.FaceTracker

## FaceBlur

::: pymotion.ai.FaceBlur

## VoiceConversion

::: pymotion.ai.VoiceConversion

## MusicGeneration

::: pymotion.ai.MusicGeneration

## SoundFXGeneration

::: pymotion.ai.SoundFXGeneration
